@@ -3,6 +3,10 @@
 #' @export
 #' @title Set cell borders
 #' @description change borders of selected rows and columns of a flextable.
+#' This function is not to be used by end user (it requires careful
+#' settings to avoid overlapping borders) but only for programming purposes.
+#' If you need to add borders, use instead functions [hline()], [vline()],
+#' [border_outer()], ...
 #' @param x a flextable object
 #' @param i rows selection
 #' @param j columns selection
@@ -13,13 +17,12 @@
 #' @param border.left border left
 #' @param border.right border right
 #' @family borders management
-#' @note this function requires careful
-#' settings to avoid overlapping borders.
 #' @examples
 #' library(officer)
 #' ftab <- flextable(head(mtcars))
 #' ftab <- border(ftab, border.top = fp_border(color = "orange") )
 #' ftab
+#' @keywords internal
 border <- function(x, i = NULL, j = NULL, border = NULL,
                    border.top = NULL, border.bottom = NULL,
                    border.left = NULL, border.right = NULL,
@@ -107,7 +110,7 @@ border_remove <- function(x){
 #' or all parts of a flextable.
 #' @param x a flextable object
 #' @param part partname of the table (one of 'all', 'body', 'header', 'footer')
-#' @param border border defined by a call to \code{\link[officer]{fp_border}}
+#' @param border border properties defined by a call to [fp_border()]
 #' @export
 #' @examples
 #' library(officer)
@@ -128,6 +131,9 @@ border_outer <- function(x, border = NULL, part = "all"){
   part <- match.arg(part, c("all", "body", "header", "footer"), several.ok = FALSE )
   if( !inherits(x, "flextable") ) stop("border_outer supports only flextable objects.")
 
+  if(is.null(border))
+    border <- fp_border(color = flextable_global$defaults$border.color)
+
   if( part == "all" ){
     for( p in c("header", "body", "footer") ){
       x <- border_outer(x = x, border = border, part = p)
@@ -168,6 +174,9 @@ border_inner_h <- function(x, border = NULL, part = "body"){
   if( !inherits(x, "flextable") ) stop("border_inner_h supports only flextable objects.")
   part <- match.arg(part, c("all", "body", "header", "footer"), several.ok = FALSE )
 
+  if(is.null(border))
+    border <- fp_border(color = flextable_global$defaults$border.color)
+
   if( part == "all" ){
     for( p in c("header", "body", "footer") ){
       x <- border_inner_h(x = x, border = border, part = p)
@@ -206,6 +215,9 @@ border_inner_v <- function(x, border = NULL, part = "all"){
   if( !inherits(x, "flextable") ) stop("border_inner_v supports only flextable objects.")
   part <- match.arg(part, c("all", "body", "header", "footer"), several.ok = FALSE )
 
+  if(is.null(border))
+    border <- fp_border(color = flextable_global$defaults$border.color)
+
   if( part == "all" ){
     for( p in c("header", "body", "footer") ){
       x <- border_inner_v(x = x, border = border, part = p)
@@ -244,6 +256,9 @@ border_inner <- function(x, border = NULL, part = "all"){
   if( !inherits(x, "flextable") ) stop("border_inner_v supports only flextable objects.")
   part <- match.arg(part, c("all", "body", "header", "footer"), several.ok = FALSE )
 
+  if(is.null(border))
+    border <- fp_border(color = flextable_global$defaults$border.color)
+
   if( part == "all" ){
     for( p in c("header", "body", "footer") ){
       x <- border_inner(x = x, border = border, part = p)
@@ -291,6 +306,9 @@ hline <- function(x, i = NULL, j = NULL, border = NULL, part = "body"){
   if( !inherits(x, "flextable") ) stop("hline supports only flextable objects.")
   part <- match.arg(part, c("all", "body", "header", "footer"), several.ok = FALSE )
 
+  if(is.null(border))
+    border <- fp_border(color = flextable_global$defaults$border.color)
+
   if( part == "all" ){
     for( p in c("header", "body", "footer") ){
       x <- hline(x = x, i = i, j = j,
@@ -341,6 +359,9 @@ hline_top <- function(x, j = NULL, border = NULL, part = "body"){
   if( !inherits(x, "flextable") ) stop("hline_top supports only flextable objects.")
   part <- match.arg(part, c("all", "body", "header", "footer"), several.ok = FALSE )
 
+  if(is.null(border))
+    border <- fp_border(color = flextable_global$defaults$border.color)
+
   if( part == "all" ){
     for( p in c("header", "body", "footer") ){
       x <- hline_top(x = x, j = j, border = border, part = p)
@@ -352,7 +373,15 @@ hline_top <- function(x, j = NULL, border = NULL, part = "body"){
     return(x)
 
   j <- get_columns_id(x[[part]], j )
-  x <- border(x, i = 1, j = j, border.top = border, part = part )
+
+  if(part %in% "body" && nrow_part(x, "header")>0){
+    x <- border(x, i = nrow_part(x, "header"), j = j, border.bottom = border, part = "header" )
+  } else if(part %in% "footer" && nrow_part(x, "body")>0){
+    x <- border(x, i = nrow_part(x, "body"), j = j, border.bottom = border, part = "body" )
+  } else {
+    x <- border(x, i = 1, j = j, border.top = border, part = part )
+  }
+
   x
 }
 
@@ -381,6 +410,9 @@ hline_bottom <- function(x, j = NULL, border = NULL, part = "body"){
   if( !inherits(x, "flextable") ) stop("hline_bottom supports only flextable objects.")
   part <- match.arg(part, c("all", "body", "header", "footer"), several.ok = FALSE )
 
+  if(is.null(border))
+    border <- fp_border(color = flextable_global$defaults$border.color)
+
   if( part == "all" ){
     for( p in c("header", "body", "footer") ){
       x <- hline_bottom(x = x, j = j, border = border, part = p)
@@ -420,6 +452,9 @@ vline <- function(x, i = NULL, j = NULL, border = NULL, part = "all"){
   if( !inherits(x, "flextable") ) stop("vline supports only flextable objects.")
   part <- match.arg(part, c("all", "body", "header", "footer"), several.ok = FALSE )
 
+  if(is.null(border))
+    border <- fp_border(color = flextable_global$defaults$border.color)
+
   if( part == "all" ){
     for( p in c("header", "body", "footer") ){
       x <- vline(x = x, i = i, j = j, border = border, part = p)
@@ -466,6 +501,9 @@ vline_left <- function(x, i = NULL, border = NULL, part = "all"){
   if( !inherits(x, "flextable") ) stop("vline_left supports only flextable objects.")
   part <- match.arg(part, c("all", "body", "header", "footer"), several.ok = FALSE )
 
+  if(is.null(border))
+    border <- fp_border(color = flextable_global$defaults$border.color)
+
   if( part == "all" ){
     for( p in c("header", "body", "footer") ){
       x <- vline_left(x = x, i = i, border = border, part = p)
@@ -504,6 +542,9 @@ vline_right <- function(x, i = NULL, border = NULL, part = "all"){
   if( !inherits(x, "flextable") ) stop("vline_right supports only flextable objects.")
   part <- match.arg(part, c("all", "body", "header", "footer"), several.ok = FALSE )
 
+  if(is.null(border))
+    border <- fp_border(color = flextable_global$defaults$border.color)
+
   if( part == "all" ){
     for( p in c("header", "body", "footer") ){
       x <- vline_right(x = x, i = i, border = border, part = p)
